@@ -18,12 +18,17 @@ from .utils import (
     null_or_int,
     null_or_unicode,
 )
-from .exc import InvalidAttributeException, UnknownTypeException
+from .exc import (
+    AttributeTypeException,
+    InvalidAttributeException,
+    UnknownTypeException
+)
 from .fields import ModelFieldList, ModelFormField
 from .generator import FormGenerator
 
 
 __all__ = (
+    AttributeTypeException,
     DateRange,
     InvalidAttributeException,
     ModelFieldList,
@@ -42,7 +47,7 @@ __all__ = (
 )
 
 
-__version__ = '0.9.2'
+__version__ = '0.9.3'
 
 
 class ModelFormMeta(FormMeta):
@@ -84,6 +89,12 @@ def model_form_factory(base=Form, meta=ModelFormMeta, **defaults):
 
             default = None
 
+            #: Whether or not to skip unknown types. If this is set to True,
+            #: fields with types that are not present in FormGenerator type map
+            #: will be silently excluded from the generated form.
+            #:
+            #: By default this is set to False, meaning unknown types throw
+            #: exceptions when encountered.
             skip_unknown_types = defaults.get('skip_unknown_types', False)
 
             #: Whether or not to assign non-nullable fields as required
@@ -146,6 +157,14 @@ def model_form_factory(base=Form, meta=ModelFormMeta, **defaults):
                 'datetime_format', '%Y-%m-%d %H:%M:%S'
             )
 
+            #: Dictionary of SQLAlchemy types as keys and WTForms field classes
+            #: as values. The key value pairs of this dictionary override
+            #: the key value pairs of FormGenerator.TYPE_MAP.
+            #:
+            #: Using this configuration option one can easily configure the
+            #: type conversion in class level.
+            type_map = {}
+
             #: Additional fields to include in the generated form.
             include = []
 
